<?php

namespace EventPortal\Domain\Util;

use EventPortal\Domain\Form\Exceptions\NoDefaultFound;
use Illuminate\Support\Str;

class DefaultConfig
{
    /** @var \Illuminate\Support\Stringable */
    private $model;

    public function __construct(string $modelClass)
    {
        $this->model = Str::of($modelClass)->afterLast('\\')->lower();
    }

    public static function for(string $modelClass): self
    {
        return new static($modelClass);
    }

    public function fields(): array
    {
        return $this->getConfig('fields');
    }

    public function tableColumns(): array
    {
        return $this->getConfig('tableColumns');
    }

    private function getConfig(string $type): array
    {
        $config = config("defaults.{$this->model}.{$type}");

        throw_if($config === null, NoDefaultFound::class, "Config type {$type} not found.");

        return $config;
    }
}
