<?php

namespace EventPortal\Domain\Util;

use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Form;
use Illuminate\Support\Arr;

class ValidationRules
{
    public static function forForm(Form $form): array
    {
        if ($form->hasModel()) {
            return $form
                ->getModel()
                ->fields
                ->mapWithKeys(function (Field $field): array {
                    return [$field->name => $field->data->get('validation')];
                })
                ->filter()
                ->toArray();
        }

        return collect($form->content)
            ->flatMap(function ($section) {
                return Arr::get($section, 'children');
            })
            ->mapWithKeys(function ($field) {
                return [
                    Arr::get($field, 'name') => Arr::get($field, 'validation'),
                ];
            })
            ->filter()
            ->toArray();
    }
}
